.. _software:

Software
--------

The following software projects use **PyAutoFit**:

`PyAutoLens <https://github.com/Jammy2211/PyAutoLens>`_ -
Astronomy software for modeling Strong Gravitational Lenses.

`PyAutoGalaxy <https://github.com/Jammy2211/PyAutoGalaxy>`_ -
Astronomy software for modeling galaxy light profiles and dynamics.

`PyAutoCTI <https://github.com/Jammy2211/PyAutoCTI>`_ -
Software for modeling Charge Transfer Inefficiency induced by radiation damage to CCDs.